@@ -27,4 +27,10 @@ class TestCase(unittest.TestCase):
         res = set()
         for it in z.mysql_iter_table(self.client, table="sca.t_std_org", where_condition="is_deleted=0", offset_limit="limit 10"):
             res.add(it["code"])
-        self.assertEqual(len(res), 10)
\ No newline at end of file
+        self.assertEqual(len(res), 10)
+        
+        for it in z.mysql_iter_table(self.client, table="sca.t_std_org", fields={"code"}, where_condition="is_deleted=0", offset_limit="limit 10"):
+            self.assertSetEqual(set(it.keys()), {"code"})
+        
+        for it in z.mysql_iter_table(self.client, table="sca.t_std_org", fields={"code", "name"}, where_condition="is_deleted=0", offset_limit="limit 10"):
+            self.assertSetEqual(set(it.keys()), {"code", "name"})
\ No newline at end of file
